@@ -34,7 +34,7 @@ def parse_to_python_object(string):
             sert, src = match.groups()
             yield sert, src    
                         
-    string_regex = re.compile(r"(?:(?:\"([(\\\")\w\s\\\.\[\]\*/~:()#@!&<>-]*)\")|([\w\.@-]*))(.*)",
+    string_regex = re.compile(r"(?:(?:\"([(\\\")\w\s\\\.\[\]\*\/~:()#@!&<>-]*)\")|([\w\d\.#@-]*))(.*)",
                               re.DOTALL)
     
     def parse_string(src):
